==> mono_1.1.12.1.orig.tar.gz: mono-1.1.12.1/mcs/class/corlib/System.Runtime.Remoting.Messaging/IMethodMessage.cs <==
//
// System.Runtime.Remoting.Messaging.IMethodMessage..cs
//
// Author:
//   Miguel de Icaza (miguel@ximian.com)
//
// (C) Ximian, Inc.  http://www.ximian.com
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Reflection;

namespace System.Runtime.Remoting.Messaging {

	public interface IMethodMessage : IMessage {
		int       ArgCount        {
			get;
		}
		
		object [] Args            {
			get;
		}
		
		bool      HasVarArgs      {
			get;
		}

		LogicalCallContext LogicalCallContext {
			get;
		}

		MethodBase MethodBase {
			get;
		}

		string MethodName {
			get;
		}

		object MethodSignature {
			get;
		}

		string TypeName {
			get;
		}

		string Uri {
			get;
		}

		object GetArg     (int arg_num);
		string GetArgName (int arg_num);
	}
}

==> mono_5.18.0.240+dfsg.orig.tar.gz: mono-5.18.0.240+dfsg/mcs/class/corlib/System.Runtime.Remoting.Messaging/IMethodMessage.cs <==
//
// System.Runtime.Remoting.Messaging.IMethodMessage.cs
//
// Author:
//   Miguel de Icaza (miguel@ximian.com)
//
// (C) Ximian, Inc.  http://www.ximian.com
//

//
// Copyright (C) 2004 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System.Reflection;

namespace System.Runtime.Remoting.Messaging {

	[System.Runtime.InteropServices.ComVisible (true)]
	public interface IMethodMessage : IMessage {
		int       ArgCount        {
			get;
		}
		
		object [] Args            {
			get;
		}
		
		bool      HasVarArgs      {
			get;
		}

		LogicalCallContext LogicalCallContext {
			get;
		}

		MethodBase MethodBase {
			get;
		}

		string MethodName {
			get;
		}

		object MethodSignature {
			get;
		}

		string TypeName {
			get;
		}

		string Uri {
			get;
		}

		object GetArg     (int argNum);
		string GetArgName (int index);
	}
}
